spawn

Function spawn 

pub unsafe fn spawn(ctx: Context) -> Result<Child, Error>
Spawn a child process, returning a Child. For safety, this function cannot return until the child has been executed. This is because the child entrypoints may borrow memory from the parent.

Note: This function may allocate, because it never needs to run in an async-signal-safe context.

Safety

The pointers in ctx must be valid until this function returns.